package com.flossom.system.service;


import com.flossom.common.core.domain.entity.IntegralGlobal;

import java.util.List;

/**
 * 奖励积分Service接口
 *
 * @author flossom
 * @date 2023-12-11
 */
public interface IIntegralGlobalService
{
    /**
     * 查询奖励积分
     *
     * @param id 奖励积分主键
     * @return 奖励积分
     */
    public IntegralGlobal selectIntegralGlobalById(Long id);

    /**
     * 查询奖励积分列表
     *
     * @param integralGlobal 奖励积分
     * @return 奖励积分集合
     */
    public List<IntegralGlobal> selectIntegralGlobalList(IntegralGlobal integralGlobal);

    /**
     * 新增奖励积分
     *
     * @param integralGlobal 奖励积分
     * @return 结果
     */
    public int insertIntegralGlobal(IntegralGlobal integralGlobal);

    /**
     * 修改奖励积分
     *
     * @param integralGlobal 奖励积分
     * @return 结果
     */
    public int updateIntegralGlobal(IntegralGlobal integralGlobal);

    /**
     * 批量删除奖励积分
     *
     * @param ids 需要删除的奖励积分主键集合
     * @return 结果
     */
    public int deleteIntegralGlobalByIds(Long[] ids);

    /**
     * 删除奖励积分信息
     *
     * @param id 奖励积分主键
     * @return 结果
     */
    public int deleteIntegralGlobalById(Long id);
}
